@@ -4,3 +4,5 @@ from instascrape.core._static_scraper import _StaticHtmlScraper
 
 class LoginAndSignupPage(_StaticHtmlScraper):
     _Mapping = _LoginMapping
+    def _construct_url(self):
+        pass
\ No newline at end of file
